"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNodeConfiguration = exports.getEsmConfiguration = exports.getCjsConfiguration = void 0;
/*!
 * Copyright (c) Microsoft. All rights reserved.
 * Licensed under the MIT license. See LICENSE file in the project.
 */
const fs_1 = require("fs");
const path_1 = require("path");
const createBabelConfig_1 = require("./createBabelConfig");
const getBrowsersList_1 = require("./getBrowsersList");
__exportStar(require("./createBabelConfig"), exports);
const cwd = process.cwd();
const packageJsonPath = path_1.join(cwd, 'package.json');
const packageJson = fs_1.existsSync('package.json') ? require(packageJsonPath) : {};
const babelEsmOverride = path_1.join(cwd, 'babel.esm.js');
const babelCjsOverride = path_1.join(cwd, 'babel.cjs.js');
const useBuiltIns = packageJson.useBuiltIns || 'usage';
const corejs = packageJson.corejs || (useBuiltIns ? { version: 3 } : undefined);
/**
 * Gets the babel CJS configuration
 * @param env The babel env to use
 */
function getCjsConfiguration(env, spec = {}) {
    // ALlows users to override default cjs emission
    // during build by defining 'babel.cjs.js'
    if (fs_1.existsSync(babelCjsOverride)) {
        return require(babelCjsOverride);
    }
    return createBabelConfig_1.createBabelConfig({
        modules: 'cjs',
        targets: getBrowsersList_1.getBrowsersList(env, packageJson.browserslist),
        useBuiltIns,
        corejs,
        ...spec,
    });
}
exports.getCjsConfiguration = getCjsConfiguration;
/**
 * Gets the babel ESM configuration
 * @param env The babel env to use
 */
function getEsmConfiguration(env, spec = {}) {
    // ALlows users to override default esm emission
    // during build by defining 'babel.esm.js'
    if (fs_1.existsSync(babelEsmOverride)) {
        return require(babelEsmOverride);
    }
    return createBabelConfig_1.createBabelConfig({
        modules: 'esm',
        targets: getBrowsersList_1.getBrowsersList(env, packageJson.browserslist),
        useBuiltIns,
        corejs,
        ...spec,
    });
}
exports.getEsmConfiguration = getEsmConfiguration;
/**
 * Gets node-compatible configuration to use
 * with the current node version that supports
 * TypeScript & React. Usable for Jest testing.
 */
function getNodeConfiguration(spec = {}) {
    return createBabelConfig_1.createBabelConfig({
        modules: 'cjs',
        targets: { node: 'current' },
        presets: [
            require('@babel/preset-typescript'),
            require('@babel/preset-react'),
        ],
        ...spec,
    });
}
exports.getNodeConfiguration = getNodeConfiguration;
